==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ca.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enllaç públic",
    "Photos" : "Fotos",
    "On This Day" : "Aquest mateix dia",
    "Your memories under your control" : "Els vostres records sota control",
    "All media" : "Tot el contingut",
    "Videos" : "Vídeos",
    "Albums" : "Àlbums",
    "Collaborative albums" : "Àlbums col·laboratius",
    "People" : "Persones",
    "Folders" : "Carpetes",
    "Favorites" : "Preferits",
    "On this day" : "Aquest mateix dia",
    "Shared with you" : "Compartit amb vós",
    "Tags" : "Etiquetes",
    "Places" : "Llocs",
    "Map" : "Mapa",
    "Photos settings" : "Paràmetres de Fotos",
    "Mark selection as favorite" : "Marca la selecció com a preferida",
    "Add selection to favorites" : "Afegeix la selecció als preferits",
    "Remove selection from favorites" : "Suprimeix la selecció dels preferits",
    "Name of the album" : "Nom de l'àlbum",
    "Location of the album" : "Lloc de l'àlbum",
    "Back" : "Torna",
    "Add collaborators" : "Afegeix col·laboradors",
    "Save" : "Desa",
    "Create album" : "Crea l'àlbum",
    "Add to Album" : "Afegeix a l'àlbum",
    "Add selection to album {albumName}" : "Afegeix la selecció a l'àlbum {albumName}",
    "Shared by" : "Compartit per",
    "Create a new album." : "Creeu un àlbum nou.",
    "Create new album" : "Crea un àlbum",
    "New album" : "Àlbum nou",
    "_%n item_::_%n photos and videos_" : ["%n element","%n fotos i vídeos"],
    "Failed to fetch collaborators list." : "No s'ha pogut obtenir la llista de col·laboradors.",
    "Failed to update album." : "No s'ha pogut actualitzar l'àlbum.",
    "Add people or groups who can edit your album" : "Afegiu persones o grups que puguin editar l'àlbum",
    "Search people or groups" : "Cerqueu persones o grups",
    "No recommendations. Start typing." : "No hi ha cap recomanació. Comenceu a escriure.",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "Suprimeix {collaboratorLabel} de la llista de col·laboradors",
    "Copy the public link" : "Copia l'enllaç públic",
    "Public link copied!" : "S'ha copiat l'enllaç públic!",
    "Copy public link" : "Copia l'enllaç públic",
    "Delete the public link" : "Suprimeix l'enllaç públic",
    "Create public link share" : "Crea un element compartit per enllaç públic",
    "Share via public link" : "Comparteix mitjançant un enllaç públic",
    "This collection does not exist" : "Aquesta col·lecció no existeix",
    "An error occurred" : "S'ha produït un error",
    "No picture for this day" : "No hi ha cap foto per a aquest dia",
    "Picture taken on this day will show up here." : "Les fotos fetes aquest dia es mostraran aquí.",
    "More photos from this day" : "Més fotos d'aquest dia",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sense assignar","%n fotos sense assignar"],
    "Favorite" : "Afegeix als preferits",
    "Favorite image, open the full size \"{name}\" image" : "Imatge preferida, obre la imatge «{name}» a mida completa",
    "Open the full size \"{name}\" image" : "Obre la imatge «{name}» a mida completa",
    "Select image {imageName}" : "Selecciona la imatge {imageName}",
    "Open the \"{name}\" folder" : "Obre la carpeta «{name}»",
    "Back to {folder}" : "Torna a {folder}",
    "Go back" : "Torna",
    "Share this folder" : "Comparteix la carpeta",
    "Dates" : "Dates",
    "Jump to specific date in list" : "Salta a una data específica de la llista",
    "Jump to {date}" : "Salta a {date}",
    "Add to {destination}" : "Afegeix a {destination}",
    "The destination folder is owned by {owner}" : "La carpeta de destinació és propietat de {owner}",
    "There are no photos or videos yet!" : "Encara no hi ha cap foto ni vídeo!",
    "_{years} year ago_::_{years} years ago_" : ["Fa {years} any","Fa {years} anys"],
    "Enable squared photos view" : "Habilita la visualització de fotos quadrada",
    "Delete source directory" : "Suprimeix la carpeta d'origen",
    "Pick folder" : "Trieu la carpeta",
    "Select a source folder for your media" : "Trieu una carpeta d'origen per al contingut multimèdia",
    "All folders" : "Totes les carpetes",
    "Add a Photos source for the timelines" : "Afegiu un origen de fotos per a les cronologies",
    "Add folder" : "Afegeix una carpeta",
    "Select the default upload location for your media" : "Seleccioneu la ubicació de pujada per defecte per al contingut multimèdia",
    "Home" : "Casa",
    "Choose default Photos upload and Albums location" : "Tria la ubicació per defecte de les pujades de fotos i dels àlbums",
    "Choose a different folder" : "Tria una carpeta diferent",
    "View" : "Visualització",
    "Media folders" : "Carpetes multimèdia",
    "Choose the folders from where photos and videos are shown." : "Trieu les carpetes de les quals es mostren les fotos i els vídeos.",
    "Upload folder" : "Carpeta de pujada",
    "Choose the folder where photos and albums are uploaded to." : "Trieu la carpeta on es pugen les fotos i els àlbums.",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos"],
    "Unselect all" : "Anul·la tota la selecció",
    "Add photos to this album" : "Afegeix fotos a aquest àlbum",
    "Manage collaborators for this album" : "Administra els col·laboradors d'aquest àlbum",
    "Open actions menu" : "Obre el menú d'accions",
    "Edit album details" : "Edita els detalls de l'àlbum",
    "Download all files in album" : "Baixa tots els fitxers de l'àlbum",
    "Delete album" : "Suprimeix l'àlbum",
    "Download selected files" : "Baixa els fitxers seleccionats",
    "Remove selection from album" : "Suprimeix la selecció de l'àlbum",
    "This album does not have any photos or videos yet!" : "Aquest àlbum encara no té cap foto ni vídeo!",
    "Add photos to {albumName}" : "Afegeix fotos a {albumName}",
    "Manage collaborators" : "Administra els col·laboradors",
    "Save collaborators for this album." : "Deseu els col·laboradors per a aquest àlbum.",
    "Cover photo for album {albumName}" : "Foto de portada de l'àlbum {albumName}",
    "There is no album yet!" : "Encara no hi ha cap àlbum!",
    "This person could not be found" : "No s'ha pogut trobar aquesta persona",
    "Rename person" : "Canvia el nom de la persona",
    "Merge with different person" : "Fusiona amb una altra persona",
    "Download selected photos" : "Baixa les fotos seleccionades",
    "Remove from favorites" : "Suprimeix dels preferits",
    "Remove person" : "Suprimeix la persona",
    "Name of this person" : "Nom d'aquesta persona",
    "Save." : "Desa.",
    "Merge person" : "Fusiona la persona",
    "Move to different person" : "Mou a una altra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mou la foto a una altra persona","Mou les fotos a una altra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Suprimeix la foto de la persona","Suprimeix les fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Això pot tardar una mica, en funció de la mida de la biblioteca de fotos.",
    "Recognized people will show up here" : "Les persones reconegudes es mostraran aquí",
    "This folder does not exist" : "Aquesta carpeta no existeix",
    "Loading folders …" : "S'estan carregant les carpetes…",
    "No photos in here" : "No hi ha cap foto aquí",
    "Taken on {date} at {time}" : "Fotografia feta el {date} a les {time}",
    "This place does not have any photos or videos yet!" : "Aquest lloc encara no té cap foto ni vídeo!",
    "Add photos to this place" : "Afegeix fotos a aquest lloc",
    "Cover photo for place {placeName}" : "Foto de portada del lloc {placeName}",
    "There is no place yet!" : "Encara no hi ha cap lloc!",
    "Back to tags overview" : "Torna a la visualització general d'etiquetes",
    "No photos with this tag yet" : "Encara no hi ha cap foto amb aquesta etiqueta",
    "No tags yet" : "Encara no hi ha cap etiqueta",
    "Photos with tags will show up here" : "Les fotos amb etiquetes es mostraran aquí",
    "Popular tags" : "Etiquetes populars",
    "All tags" : "Totes les etiquetes",
    "One of the source folders does not exist" : "Una de les carpetes font no existeix",
    "Add to album" : "Afegeix a un àlbum",
    "Delete selection" : "Suprimeix la selecció",
    "No photos or videos in here" : "No hi ha cap foto ni vídeo aquí",
    "Unassigned faces" : "Cares sense assignar",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos"],
    "Failed to fetch collection." : "No s'ha pogut obtenir la col·lecció.",
    "Failed to fetch collections list." : "No s'ha pogut obtenir la llista de col·leccions.",
    "Failed to fetch faces list." : "No s'ha pogut obtenir la llista de cares.",
    "All your media" : "Tot el contingut",
    "Album {title}" : "Àlbum {title}",
    "Shared Albums" : "Àlbums compartits",
    "Shared album {title}" : "Àlbum compartit {title}",
    "Public album {title}" : "Àlbum públic {title}",
    "Tagged photos" : "Fotos etiquetades",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Cara de {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalls",
    "Could not load photos folder" : "No s'ha pogut carregar la carpeta de fotos",
    "One of the source folders does not exists" : "Una de les carpetes d'origen no existeix",
    "Add" : "Afegeix"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/ca.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Enllaç públic",
    "Photos" : "Fotos",
    "On This Day" : "Aquest mateix dia",
    "Your memories under your control" : "Els vostres records sota control",
    "All media" : "Tot el contingut",
    "Videos" : "Vídeos",
    "Albums" : "Àlbums",
    "Collaborative albums" : "Àlbums col·laboratius",
    "People" : "Persones",
    "Folders" : "Carpetes",
    "Favorites" : "Preferits",
    "On this day" : "Aquest mateix dia",
    "Shared with you" : "Compartit amb vós",
    "Tags" : "Etiquetes",
    "Places" : "Llocs",
    "Map" : "Mapa",
    "Photos settings" : "Paràmetres de Fotos",
    "Mark selection as favorite" : "Marca la selecció com a preferida",
    "Add selection to favorites" : "Afegeix la selecció als preferits",
    "Remove selection from favorites" : "Suprimeix la selecció dels preferits",
    "This name is already in use." : "Aquest nom ja s'utilitza.",
    "\"{char}\" is not allowed inside a filename." : "\"{char}\" no és permès dins d'un nom de fitxer.",
    "Invalid filename." : "Nom de fitxer no vàlid.",
    "Name of the album" : "Nom de l'àlbum",
    "Location of the album" : "Lloc de l'àlbum",
    "Back" : "Torna",
    "Add collaborators" : "Afegeix col·laboradors",
    "Save" : "Desa",
    "Create album" : "Crea l'àlbum",
    "Add to Album" : "Afegeix a l'àlbum",
    "Add selection to album {albumName}" : "Afegeix la selecció a l'àlbum {albumName}",
    "Shared by" : "Compartit per",
    "Create a new album." : "Creeu un àlbum nou.",
    "Create new album" : "Crea un àlbum",
    "New album" : "Àlbum nou",
    "_%n item_::_%n photos and videos_" : ["%n element","%n fotos i vídeos"],
    "Failed to fetch collaborators list." : "No s'ha pogut obtenir la llista de col·laboradors.",
    "Failed to update album." : "No s'ha pogut actualitzar l'àlbum.",
    "Add people or groups who can edit your album" : "Afegiu persones o grups que puguin editar l'àlbum",
    "Search people or groups" : "Cerqueu persones o grups",
    "No recommendations. Start typing." : "No hi ha cap recomanació. Comenceu a escriure.",
    "Copy the public link" : "Copia l'enllaç públic",
    "Public link copied!" : "S'ha copiat l'enllaç públic!",
    "Copy public link" : "Copia l'enllaç públic",
    "Delete the public link" : "Suprimeix l'enllaç públic",
    "Create public link share" : "Crea un element compartit per enllaç públic",
    "Share via public link" : "Comparteix mitjançant un enllaç públic",
    "This collection does not exist" : "Aquesta col·lecció no existeix",
    "An error occurred" : "S'ha produït un error",
    "No picture for this day" : "No hi ha cap foto per a aquest dia",
    "Picture taken on this day will show up here." : "Les fotos fetes aquest dia es mostraran aquí.",
    "More photos from this day" : "Més fotos d'aquest dia",
    "_%n photos_::_%n photos_" : ["%n foto","%n fotos"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto sense assignar","%n fotos sense assignar"],
    "Favorite" : "Afegeix als preferits",
    "Favorite image, open the full size \"{name}\" image" : "Imatge preferida, obre la imatge «{name}» a mida completa",
    "Open the full size \"{name}\" image" : "Obre la imatge «{name}» a mida completa",
    "Select image {imageName}" : "Selecciona la imatge {imageName}",
    "Open the \"{name}\" folder" : "Obre la carpeta «{name}»",
    "Go back" : "Torna",
    "Dates" : "Dates",
    "Jump to specific date in list" : "Salta a una data específica de la llista",
    "Jump to {date}" : "Salta a {date}",
    "Add to {destination}" : "Afegeix a {destination}",
    "The destination folder is owned by {owner}" : "La carpeta de destinació és propietat de {owner}",
    "There are no photos or videos yet!" : "Encara no hi ha cap foto ni vídeo!",
    "_{years} year ago_::_{years} years ago_" : ["Fa {years} any","Fa {years} anys"],
    "Delete source directory" : "Suprimeix la carpeta d'origen",
    "Pick folder" : "Trieu la carpeta",
    "Select a source folder for your media" : "Trieu una carpeta d'origen per al contingut multimèdia",
    "Media folders" : "Carpetes multimèdia",
    "Choose the folders from where photos and videos are shown." : "Trieu les carpetes de les quals es mostren les fotos i els vídeos.",
    "All folders" : "Totes les carpetes",
    "Add a Photos source for the timelines" : "Afegiu un origen de fotos per a les cronologies",
    "Add folder" : "Afegeix una carpeta",
    "Home" : "Casa",
    "Select the default upload location for your media" : "Seleccioneu la ubicació de pujada per defecte per al contingut multimèdia",
    "Upload folder" : "Carpeta de pujada",
    "General" : "General",
    "_%n photo_::_%n photos_" : ["%n foto","%n fotos"],
    "Unselect all" : "Anul·la tota la selecció",
    "Add photos to this album" : "Afegeix fotos a aquest àlbum",
    "Manage collaborators for this album" : "Administra els col·laboradors d'aquest àlbum",
    "Open actions menu" : "Obre el menú d'accions",
    "Edit album details" : "Edita els detalls de l'àlbum",
    "Download all files in album" : "Baixa tots els fitxers de l'àlbum",
    "Delete album" : "Suprimeix l'àlbum",
    "Download selected files" : "Baixa els fitxers seleccionats",
    "Remove selection from album" : "Suprimeix la selecció de l'àlbum",
    "This album does not have any photos or videos yet!" : "Aquest àlbum encara no té cap foto ni vídeo!",
    "Add photos to {albumName}" : "Afegeix fotos a {albumName}",
    "Manage collaborators" : "Administra els col·laboradors",
    "Save collaborators for this album." : "Deseu els col·laboradors per a aquest àlbum.",
    "Cover photo for album {albumName}" : "Foto de portada de l'àlbum {albumName}",
    "There is no album yet!" : "Encara no hi ha cap àlbum!",
    "This person could not be found" : "No s'ha pogut trobar aquesta persona",
    "Rename person" : "Canvia el nom de la persona",
    "Merge with different person" : "Fusiona amb una altra persona",
    "Download selected photos" : "Baixa les fotos seleccionades",
    "Remove from favorites" : "Suprimeix dels preferits",
    "Remove person" : "Suprimeix la persona",
    "Name of this person" : "Nom d'aquesta persona",
    "Save." : "Desa.",
    "Merge person" : "Fusiona la persona",
    "Move to different person" : "Mou a una altra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Mou la foto a una altra persona","Mou les fotos a una altra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Suprimeix la foto de la persona","Suprimeix les fotos de la persona"],
    "This might take some time depending on the size of your photo library." : "Això pot tardar una mica, en funció de la mida de la biblioteca de fotos.",
    "Recognized people will show up here" : "Les persones reconegudes es mostraran aquí",
    "This folder does not exist" : "Aquesta carpeta no existeix",
    "Loading folders…" : "S'està carregant les carpetes…",
    "No photos in here" : "No hi ha cap foto aquí",
    "Taken on {date} at {time}" : "Fotografia feta el {date} a les {time}",
    "This place does not have any photos or videos yet!" : "Aquest lloc encara no té cap foto ni vídeo!",
    "Add photos to this place" : "Afegeix fotos a aquest lloc",
    "Cover photo for place {placeName}" : "Foto de portada del lloc {placeName}",
    "There is no place yet!" : "Encara no hi ha cap lloc!",
    "Back to tags overview" : "Torna a la visualització general d'etiquetes",
    "No photos with this tag yet" : "Encara no hi ha cap foto amb aquesta etiqueta",
    "No tags yet" : "Encara no hi ha cap etiqueta",
    "Photos with tags will show up here" : "Les fotos amb etiquetes es mostraran aquí",
    "Popular tags" : "Etiquetes populars",
    "All tags" : "Totes les etiquetes",
    "One of the source folders does not exist" : "Una de les carpetes font no existeix",
    "Add to album" : "Afegeix a un àlbum",
    "Delete selection" : "Suprimeix la selecció",
    "No photos or videos in here" : "No hi ha cap foto ni vídeo aquí",
    "Unassigned faces" : "Cares sense assignar",
    "Failed to fetch collection." : "No s'ha pogut obtenir la col·lecció.",
    "Failed to fetch collections list." : "No s'ha pogut obtenir la llista de col·leccions.",
    "Failed to fetch faces list." : "No s'ha pogut obtenir la llista de cares.",
    "All your media" : "Tot el contingut",
    "Album {title}" : "Àlbum {title}",
    "Shared Albums" : "Àlbums compartits",
    "Shared album {title}" : "Àlbum compartit {title}",
    "Public album {title}" : "Àlbum públic {title}",
    "Tagged photos" : "Fotos etiquetades",
    "Tagged photo {title}" : "Foto etiquetada {title}",
    "{title}'s face" : "Cara de {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Detalls",
    "Cancel" : "Cancel",
    "Confirm" : "Confirma",
    "Could not load photos folder" : "No s'ha pogut carregar la carpeta de fotos",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "Suprimeix {collaboratorLabel} de la llista de col·laboradors",
    "Back to {folder}" : "Torna a {folder}",
    "Share this folder" : "Comparteix la carpeta",
    "Enable squared photos view" : "Habilita la visualització de fotos quadrada",
    "Choose default Photos upload and Albums location" : "Tria la ubicació per defecte de les pujades de fotos i dels àlbums",
    "Choose a different folder" : "Tria una carpeta diferent",
    "View" : "Visualització",
    "Choose the folder where photos and albums are uploaded to." : "Trieu la carpeta on es pugen les fotos i els àlbums.",
    "Loading folders …" : "S'estan carregant les carpetes…",
    "Add" : "Afegeix"
},
"nplurals=2; plural=(n != 1);");
